@@ -1,12 +1,13 @@
 #' 1D LGCP bin count simulation and comparison with data
 #'
-#' A common procedure of analyzing the distribution of 1D points is to chose a binning
-#' and plot the data's histogram with respect to this binning. This function compares the
-#' counts that the histogram calculates to simulations from a 1D log Gaussian Cox process
-#' conditioned on the number of data samples. For each bin this results in a median number
-#' of counts as well as a confidence interval. If the LGCP is a plausible model for the
-#' observed points then most of the histogram counts (number of points within a bin)
-#' should be within the confidence intervals. Note that a proper comparison  is a multiple
+#' A common procedure of analyzing the distribution of 1D points is to chose a
+#' binning and plot the data's histogram with respect to this binning. This
+#' function compares the counts that the histogram calculates to simulations
+#' from a 1D log Gaussian Cox process conditioned on the number of data samples.
+#' For each bin this results in a median number of counts as well as a
+#' confidence interval. If the LGCP is a plausible model for the observed points
+#' then most of the histogram counts (number of points within a bin) should be
+#' within the confidence intervals. Note that a proper comparison  is a multiple
 #' testing problem which the function does not solve for you.
 #'
 #'
@@ -14,30 +15,38 @@
 #' @export
 #' @importFrom graphics hist
 #' @param result A result object from a [bru()] or [lgcp()] call
-#' @param predictor A formula describing the prediction of a 1D LGCP via [predict()].
+#' @param predictor A formula describing the prediction of a 1D LGCP via
+#'   [predict()].
 #' @param observations A vector of observed values
 #' @param breaks A vector of bin boundaries
-#' @param nint Number of integration points per bin. Increase this if the bins are wide and
+#' @param nint Number of integration points per bin. Increase this if the bins
+#'   are wide and
 #' @param probs numeric vector of probabilities with values in `[0,1]`
 #' @param \dots arguments passed on to [predict.bru()]
 #' @return An `data.frame` with a ggplot attribute `ggp`
 #' @importFrom rlang .data
 #' @examples
 #' \dontrun{
-#' if (require(ggplot2)) {
+#' if (require(ggplot2) && require(fmesher)) {
 #'   # Load a point pattern
 #'   data(Poisson2_1D)
 #'
 #'   # Take a look at the point (and frequency) data
 #'
 #'   ggplot(pts2) +
-#'     geom_histogram(aes(x = x), binwidth = 55 / 20, boundary = 0, fill = NA, color = "black") +
+#'     geom_histogram(
+#'       aes(x = x),
+#'       binwidth = 55 / 20,
+#'       boundary = 0,
+#'       fill = NA,
+#'       color = "black"
+#'     ) +
 #'     geom_point(aes(x), y = 0, pch = "|", cex = 4) +
 #'     coord_fixed(ratio = 1)
 #'
 #'   # Fit an LGCP model
-#'   x <- seq(0, 55, length = 50)
-#'   mesh1D <- inla.mesh.1d(x, boundary = "free")
+#'   x <- seq(0, 55, length.out = 50)
+#'   mesh1D <- fm_mesh_1d(x, boundary = "free")
 #'   mdl <- x ~ spde1D(x, model = inla.spde2.matern(mesh1D)) + Intercept(1)
 #'   fit.spde <- lgcp(mdl, pts2, domain = list(x = c(0, 55)))
 #'
@@ -45,7 +54,7 @@
 #'   bc <- bincount(
 #'     result = fit.spde,
 #'     observations = pts2,
-#'     breaks = seq(0, max(pts2), length = 12),
+#'     breaks = seq(0, max(pts2), length.out = 12),
 #'     predictor = x ~ exp(spde1D + Intercept)
 #'   )
 #'
@@ -61,7 +70,8 @@ bincount <- function(result, predictor, observations, breaks, nint = 20,
   probs <- sort(probs)
 
   # Filter out observations outside bins
-  observations <- observations[(observations >= min(breaks)) & (observations <= max(breaks))]
+  observations <- observations[(observations >= min(breaks)) &
+    (observations <= max(breaks))]
 
   # Number of ...
   nobs <- length(observations) # observations
@@ -71,7 +81,12 @@ bincount <- function(result, predictor, observations, breaks, nint = 20,
   mid <- breaks[1:(length(breaks) - 1)] + diff(breaks) / 2
 
   # Create integration points
-  ip <- int.quadrature(breaks[1:(length(breaks) - 1)], breaks[2:(length(breaks))], scheme = "trapezoid", n.points = nint)
+  ip <- int.quadrature(
+    breaks[1:(length(breaks) - 1)],
+    breaks[2:(length(breaks))],
+    scheme = "trapezoid",
+    n.points = nint
+  )
   points <- data.frame(tmp = as.vector(ip$ips))
   colnames(points) <- all.vars(update.formula(predictor, ~.0))
   points$bin <- rep(1:nbins, each = nint)
