@@ -268,7 +268,7 @@ evaluate_effect_multi_state <- function(...) {
 #'
 #' @export
 #' @keywords internal
-#' @param component A `bru_component`, `comp_simple`, or `comp_simple_list`.
+#' @param component A `bru_mapper`, `bru_component`, `comp_simple`, or `comp_simple_list`.
 #' @param input Pre-evaluated component input
 #' @param state Specification of one (for `evaluate_effect_single_state`) or several
 #' (for `evaluate_effect_multi_State`) latent variable states:
@@ -276,14 +276,34 @@ evaluate_effect_multi_state <- function(...) {
 #' * `evaluate_effect_single_state.*_list`: list of named state vectors.
 #' * `evaluate_effect_multi_state.*_list`: list of lists of named state vectors.
 #' @param ... Optional additional parameters, e.g. `inla_f`. Normally unused.
+#' @param label Option label used for any warning messages, specifying the
+#' affected component.
 #' @author Fabian E. Bachl \email{bachlfab@@gmail.com} and
 #' Finn Lindgren \email{finn.lindgren@@gmail.com}
 #' @rdname evaluate_effect
 
 evaluate_effect_single_state.bru_mapper <- function(component, input, state,
-                                                    ...) {
+                                                    ...,
+                                                    label = NULL) {
   values <- ibm_eval(component, input = input, state = state, ...)
 
+  not_ok <- ibm_invalid_output(
+    component,
+    input = input,
+    state = state
+  )
+  if (any(not_ok)) {
+    if (is.null(label)) {
+      warning("Inputs for a mapper give some invalid outputs.",
+        immediate. = TRUE
+      )
+    } else {
+      warning("Inputs for '", label, "' give some invalid outputs.",
+        immediate. = TRUE
+      )
+    }
+  }
+
   as.vector(as.matrix(values))
 }
 
@@ -302,7 +322,8 @@ evaluate_effect_single_state.comp_simple_list <- function(components,
       components[[label]],
       input = input[[label]],
       state = state[[label]],
-      ...
+      ...,
+      label = label
     )
   }
   result
@@ -471,7 +492,16 @@ evaluate_predictor <- function(model,
           input = .input,
           state = .state
         )
-        if (.is_iid) {
+        if (!.is_iid) {
+          not_ok <- ibm_invalid_output(
+            .mapper[["mappers"]][[1]],
+            input = .input[[1]],
+            state = .state
+          )
+          if (any(not_ok)) {
+            warning("Inputs for `ibm_eval()` for '", .comp[["label"]], '" give some invalid outputs.')
+          }
+        } else { # .is_iid, invalid indices give new samples
           # Check for known invalid output elements, based on the
           # initial mapper (subsequent mappers in the component pipe
           # are assumed to keep the same length and validity)
@@ -688,38 +718,18 @@ evaluate_comp_simple <- function(...) {
 #' @rdname evaluate_comp_simple
 evaluate_comp_simple.component_list <- function(components, input,
                                                 inla_f = FALSE, ...) {
-  are_linear <- vapply(
+  mappers <- lapply(
     components,
-    function(x) ibm_is_linear(x[["mapper"]]),
-    TRUE
-  )
-  the_linear <- names(components)[are_linear]
-  the_nonlinear <- names(components)[!are_linear]
-
-  if (any(are_linear)) {
-    mappers <- comp_lin_eval(
-      components[the_linear],
-      input = input[the_linear],
-      state = NULL,
-      inla_f = inla_f
-    )
-  } else {
-    mappers <- list()
-  }
-
-  if (any(!are_linear)) {
-    warning("Non-linear mappers are experimental!", immediate. = TRUE)
-    mappers <- c(
-      mappers,
-      lapply(
-        components[the_nonlinear],
-        function(x) x[["mapper"]]
+    function(x) {
+      label <- x[["label"]]
+      ibm_simplify(
+        x[["mapper"]],
+        input[[label]],
+        state = NULL,
+        inla_f = inla_f
       )
-    )
-  }
-
-  # Reorder
-  mappers <- mappers[names(components)]
+    }
+  )
 
   class(mappers) <- c("comp_simple_list", class(mappers))
   mappers
